# puppet-uvfs

[![travis-cs status](https://travis-ci.org/wafture/puppet-uvfs.svg "travis-ci status")](https://travis-ci.org/wafture/puppet-uvfs)

#### Table of Contents

1. [Module Description - What the module does and why it is useful](#module-description)
2. [Setup - The basics of getting started with uvfs](#setup)
    * [Beginning with uvfs](#beginning-with-uvfs)
3. [Usage - Configuration options and additional functionality](#usage)
    * [Install uvfs](#install-uvfs)
4. [Reference - An under-the-hood peek at what the module is doing and how](#reference)
5. [Limitations - OS compatibility, etc.](#limitations)
6. [Development - Guide for contributing to the module](#development)

## Module Description

The UVFS module installs UVFS, the userspace filesystem kit for Linux.

## Setup

### Beginning with UVFS

To install UVFS with the default options:

`include '::uvfs'`

To customize options, such as the install directory or the version to install,
you must also pass the appropriate parameters:

```puppet
class { '::uvfs':
  version     => '2.0.6',
  install_dir => '/opt/iw-tools',
}
```

## Usage

Interactions for UVFS are all done via `::uvfs`.

### Install UVFS

To install an older version of UVFS in a non-default directory:

```puppet
class { '::uvfs':
  version     => '2.0.6',
  install_dir => '/opt/iw-tools',
}
```

## Reference

### Classes

#### Public classes

* [`uvfs`](#uvfs): Installs UVFS

#### Private classes

* `uvfs::base::install`: Installs OpenDeploy Base.
* `uvfs::base::dependencies`: Installs package dependencies for UVFS.

### Parameters

#### uvfs

##### `version`

Version of UVFS to install. Valid values are valid release numbers from SF.
Default is `2.0.7`.

#####  `install_dir`

Location, as a fully qualified path, on the filesystem to install UVFS.

Using `install_dir => '/opt/iw-tools'` will create the following structure:
```
/opt/iw-tools
	└── uvfs_2.0.7/
		└── <files installed>
```

Valid values are valid system paths. Defaults to `/opt/iw-tools`.

## Limitations

This module has been tested on:

* RedHat Enterprise Linux 6, 7
* CentOS 6, 7

Testing on other platforms is nonsensical as the vendor only supports the above
systems

## Development

See something you want to improve? Fork, clone, work, commit, and PR. Yay OSS!

### Authors

This module was created and maintained by Nick Anderson.
